==> haskell-wl-pprint-terminfo-3.7.1.4-450-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wl-pprint-terminfo.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wl-pprint-terminfo
version:              3.7.1.4
visibility:           public
id:                   wl-pprint-terminfo-3.7.1.4-8KC4w6KzEhlKRkiiZVB6Ty
key:                  wl-pprint-terminfo-3.7.1.4-8KC4w6KzEhlKRkiiZVB6Ty
license:              BSD-3-Clause
copyright:            Copyright (C) 2011 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            experimental
homepage:             http://github.com/ekmett/wl-pprint-terminfo/
synopsis:             A color pretty printer with terminfo support
description:          A color pretty printer with terminfo support
category:             Control, Monads, Text
abi:                  a2f718cf53b62860f41feb2e3f8bde51
exposed:              True
exposed-modules:      System.Console.Terminfo.PrettyPrint
hidden-modules:       System.Console.Terminfo.PrettyPrint.Curses
import-dirs:          /usr/lib/ghc-9.4.8/site-local/wl-pprint-terminfo-3.7.1.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/wl-pprint-terminfo-3.7.1.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/wl-pprint-terminfo-3.7.1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wl-pprint-terminfo
hs-libraries:         HSwl-pprint-terminfo-3.7.1.4-8KC4w6KzEhlKRkiiZVB6Ty
extra-libraries:      ncursesw
includes:             cursed.h
depends:
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7 terminfo-0.4.1.5
    text-2.0.2 transformers-0.5.6.2
    wl-pprint-extras-3.5.0.5-95B1UDNC9OfBUB2d9Dr0yw

haddock-interfaces:
    /usr/share/doc/haskell-wl-pprint-terminfo/html/wl-pprint-terminfo.haddock

haddock-html:         /usr/share/doc/haskell-wl-pprint-terminfo/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wl-pprint-terminfo-3.7.1.4-451-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wl-pprint-terminfo.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wl-pprint-terminfo
version:              3.7.1.4
visibility:           public
id:                   wl-pprint-terminfo-3.7.1.4-EE3doWU0GdQK8sXrRepS7B
key:                  wl-pprint-terminfo-3.7.1.4-EE3doWU0GdQK8sXrRepS7B
license:              BSD-3-Clause
copyright:            Copyright (C) 2011 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            experimental
homepage:             http://github.com/ekmett/wl-pprint-terminfo/
synopsis:             A color pretty printer with terminfo support
description:          A color pretty printer with terminfo support
category:             Control, Monads, Text
abi:                  cac207fd2d809cf0b441ad600cdc53e3
exposed:              True
exposed-modules:      System.Console.Terminfo.PrettyPrint
hidden-modules:       System.Console.Terminfo.PrettyPrint.Curses
import-dirs:          /usr/lib/ghc-9.4.8/site-local/wl-pprint-terminfo-3.7.1.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/wl-pprint-terminfo-3.7.1.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/wl-pprint-terminfo-3.7.1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wl-pprint-terminfo
hs-libraries:         HSwl-pprint-terminfo-3.7.1.4-EE3doWU0GdQK8sXrRepS7B
extra-libraries:      ncursesw
includes:             cursed.h
depends:
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7 terminfo-0.4.1.5
    text-2.0.2 transformers-0.5.6.2
    wl-pprint-extras-3.5.0.5-GABMy0dmcVfClCxcgpbDgF

haddock-interfaces:
    /usr/share/doc/haskell-wl-pprint-terminfo/html/wl-pprint-terminfo.haddock

haddock-html:         /usr/share/doc/haskell-wl-pprint-terminfo/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
